DRED (Dutch Residential Energy Dataset) is the first open-access, publicly available dataset from The Netherlands. The data set live deployment consists of several sensors measuring electricity, occupants occupancy and ambient parameters in a household. The DRED dataset includes:		

*  Electricity monitoring - aggregated energy consumption and appliance level energy consumption.
* Ambient information - room-level indoor temperature, outdoor temperature, environmental parameters (wind speed, humidity, precipitation).
* Occupancy information- room-level location information of occupants, WiFi and BT RSSI information for localisation
* Household information - house layout, number of appliance monitored, appliance-location mapping, etc.

The [data set homepage](http://www.st.ewi.tudelft.nl/~akshay/dred/) contains nilmtk H5 file, in addition to the raw data.

UPDATES :- 

DRED dataset converter added
The official .h5 file is not compatible with NILMTK. Use the converter instead. The converter is compatible with All_data.csv file.


